@@ -106,11 +106,20 @@ Options (* for default):
     -abs/-rel* plot relative or absolute error
     -title="note" adds note to the plot title, after the model name
     -weights shows weights plots for the polydisperse parameters
+    -profile shows the sld profile if the model has a plottable sld profile
 
     === output options ===
     -edit starts the parameter explorer
     -help/-html shows the model docs instead of running the model
 
+    === environment variables ===
+    -DSAS_MODELPATH=path sets directory containing custom models
+    -DSAS_OPENCL=vendor:device|none sets the target OpenCL device
+    -DXDG_CACHE_HOME=~/.cache sets the pyopencl cache root (linux only)
+    -DSAS_COMPILER=tinycc|msvc|mingw|unix sets the DLL compiler
+    -DSAS_OPENMP=1 turns on OpenMP for the DLLs
+    -DSAS_DLL_PATH=path sets the path to the compiled modules
+
 The interpretation of quad precision depends on architecture, and may
 vary from 64-bit to 128-bit, with 80-bit floats being common (1e-19 precision).
 On unix and mac you may need single quotes around the DLL computation
@@ -774,11 +783,57 @@ def compare(opts, limits=None, maxdim=np.inf):
             model_info = base._kernel.info
             dim = base._kernel.dim
             plot_weights(model_info, get_mesh(model_info, base_pars, dim=dim))
+        if opts['show_profile']:
+            import pylab
+            base, comp = opts['engines']
+            base_pars, comp_pars = opts['pars']
+            have_base = base._kernel.info.profile is not None
+            have_comp = (
+                comp is not None
+                and comp._kernel.info.profile is not None
+                and base_pars != comp_pars
+            )
+            if have_base or have_comp:
+                pylab.figure()
+            if have_base:
+                plot_profile(base._kernel.info, **base_pars)
+            if have_comp:
+                plot_profile(comp._kernel.info, label='comp', **comp_pars)
+                pylab.legend()
     if opts['plot']:
         import matplotlib.pyplot as plt
         plt.show()
     return limits
 
+def plot_profile(model_info, label='base', **args):
+    # type: (ModelInfo, List[Tuple[float, np.ndarray, np.ndarray]]) -> None
+    """
+    Plot the profile returned by the model profile method.
+
+    *model_info* defines model parameters, etc.
+
+    *mesh* is a list of tuples containing (*value*, *dispersity*, *weights*)
+    for each parameter, where (*dispersity*, *weights*) pairs are the
+    distributions to be plotted.
+    """
+    import pylab
+
+    args = dict((k, v) for k, v in args.items()
+                if "_pd" not in k
+                   and ":" not in k
+                   and k not in ("background", "scale", "theta", "phi", "psi"))
+    args = args.copy()
+
+    args.pop('scale', 1.)
+    args.pop('background', 0.)
+    z, rho = model_info.profile(**args)
+    #pylab.interactive(True)
+    pylab.plot(z, rho, '-', label=label)
+    pylab.grid(True)
+    #pylab.show()
+
+
+
 def run_models(opts, verbose=False):
     # type: (Dict[str, Any]) -> Dict[str, Any]
     """
@@ -948,7 +1003,8 @@ def plot_models(opts, result, limits=None, setnum=0):
 #
 OPTIONS = [
     # Plotting
-    'plot', 'noplot', 'weights',
+    'plot', 'noplot',
+    'weights', 'profile',
     'linear', 'log', 'q4',
     'rel', 'abs',
     'hist', 'nohist',
@@ -1064,8 +1120,9 @@ def parse_opts(argv):
         return None
 
     invalid = [o[1:] for o in flags
-               if o[1:] not in NAME_OPTIONS
-               and not any(o.startswith('-%s='%t) for t in VALUE_OPTIONS)]
+               if not (o[1:] in NAME_OPTIONS
+                       or any(o.startswith('-%s='%t) for t in VALUE_OPTIONS)
+                       or o.startswith('-D'))]
     if invalid:
         print("Invalid options: %s"%(", ".join(invalid)))
         return None
@@ -1102,6 +1159,7 @@ def parse_opts(argv):
         'engine'    : 'default',
         'count'     : '1',
         'show_weights' : False,
+        'show_profile' : False,
         'sphere'    : 0,
         'ngauss'    : '0',
     }
@@ -1162,8 +1220,12 @@ def parse_opts(argv):
         elif arg == '-demo':    opts['use_demo'] = True
         elif arg == '-default': opts['use_demo'] = False
         elif arg == '-weights': opts['show_weights'] = True
+        elif arg == '-profile': opts['show_profile'] = True
         elif arg == '-html':    opts['html'] = True
         elif arg == '-help':    opts['html'] = True
+        elif arg.startswith('-D'):
+            var, val = arg[2:].split('=')
+            os.environ[var] = val
     # pylint: enable=bad-whitespace,C0321
 
     # Magnetism forces 2D for now
@@ -1225,7 +1287,8 @@ def parse_opts(argv):
         opts['res'] = [float(opts['res'])]*2
 
     if opts['datafile'] is not None:
-        data = load_data(os.path.expanduser(opts['datafile']))
+        data0 = load_data(os.path.expanduser(opts['datafile']))
+        data = data0, data0
     else:
         # Hack around the fact that make_data doesn't take a pair of resolutions
         res = opts['res']
